==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/SummaryChangedEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var SummaryChangedEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(SummaryChangedEventArgsDescription, _super);
    function SummaryChangedEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.h = null;
        _this.f = false;
        return _this;
    }
    SummaryChangedEventArgsDescription.prototype.get_type = function () {
        return "SummaryChangedEventArgs";
    };
    Object.defineProperty(SummaryChangedEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SummaryChangedEventArgsDescription.prototype, "iD", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.e("ID");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SummaryChangedEventArgsDescription.prototype, "isEnabled", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("IsEnabled");
        },
        enumerable: true,
        configurable: true
    });
    SummaryChangedEventArgsDescription.$t = markType(SummaryChangedEventArgsDescription, 'SummaryChangedEventArgsDescription', Description.$);
    return SummaryChangedEventArgsDescription;
}(Description));
export { SummaryChangedEventArgsDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/SummaryChangedEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var SummaryChangedEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SummaryChangedEventArgsDescription, _super);
    function SummaryChangedEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.j = null;
        _this.h = false;
        return _this;
    }
    SummaryChangedEventArgsDescription.prototype.get_type = function () {
        return "SummaryChangedEventArgs";
    };
    Object.defineProperty(SummaryChangedEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SummaryChangedEventArgsDescription.prototype, "iD", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.g("ID");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(SummaryChangedEventArgsDescription.prototype, "isEnabled", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.g("IsEnabled");
        },
        enumerable: false,
        configurable: true
    });
    SummaryChangedEventArgsDescription.$t = markType(SummaryChangedEventArgsDescription, 'SummaryChangedEventArgsDescription', Description.$);
    return SummaryChangedEventArgsDescription;
}(Description));
export { SummaryChangedEventArgsDescription };
